pub fn statement(
layer: &str,
layer_manifest_digest: &str,
kind: AttestationKind,
bytes: &[u8],
producer: &str,
) -> AttestationStatementExpand description
Build the statement varve will sign for a set of attestation bytes.
pub fn statement(
layer: &str,
layer_manifest_digest: &str,
kind: AttestationKind,
bytes: &[u8],
producer: &str,
) -> AttestationStatementBuild the statement varve will sign for a set of attestation bytes.