pub fn write_stamp(
dir: &Path,
stamp: &ExportStamp,
) -> Result<(), ExportStampError>Expand description
Write the stamp into dir, creating dir if needed.
pub fn write_stamp(
dir: &Path,
stamp: &ExportStamp,
) -> Result<(), ExportStampError>Write the stamp into dir, creating dir if needed.